@@ -3,26 +3,23 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
-from __future__ import unicode_literals
 
 from django.db import models, migrations
 import django.db.models.deletion
 import django.utils.timezone
-from django.conf import settings
-import django_extensions.db.fields
 
-from aiida.backends.djsite.db.migrations import update_schema_version
+from aiida.backends.djsite.db.migrations import upgrade_schema_version
 
-
-
-SCHEMA_VERSION = "1.0.1"
+REVISION = '1.0.1'
+DOWN_REVISION = '1.0.0'
 
 
 class Migration(migrations.Migration):
+
     dependencies = [
         ('auth', '0001_initial'),
     ]
@@ -34,26 +31,56 @@ class Migration(migrations.Migration):
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                 ('password', models.CharField(max_length=128, verbose_name='password')),
                 ('last_login', models.DateTimeField(default=django.utils.timezone.now, verbose_name='last login')),
-                ('is_superuser', models.BooleanField(default=False,
-                                                     help_text='Designates that this user has all permissions without explicitly assigning them.',
-                                                     verbose_name='superuser status')),
+                (
+                    'is_superuser',
+                    models.BooleanField(
+                        default=False,
+                        help_text='Designates that this user has all permissions without explicitly assigning them.',
+                        verbose_name='superuser status'
+                    )
+                ),
                 ('email', models.EmailField(unique=True, max_length=75, db_index=True)),
                 ('first_name', models.CharField(max_length=254, blank=True)),
                 ('last_name', models.CharField(max_length=254, blank=True)),
                 ('institution', models.CharField(max_length=254, blank=True)),
-                ('is_staff', models.BooleanField(default=False,
-                                                 help_text=b'Designates whether the user can log into this admin site.')),
-                ('is_active', models.BooleanField(default=True,
-                                                  help_text=b'Designates whether this user should be treated as active. Unselect this instead of deleting accounts.')),
+                (
+                    'is_staff',
+                    models.BooleanField(
+                        default=False, help_text='Designates whether the user can log into this admin site.'
+                    )
+                ),
+                (
+                    'is_active',
+                    models.BooleanField(
+                        default=True,
+                        help_text=
+                        'Designates whether this user should be treated as active. Unselect this instead of deleting accounts.'
+                    )
+                ),
                 ('date_joined', models.DateTimeField(default=django.utils.timezone.now)),
-                ('groups',
-                 models.ManyToManyField(related_query_name='user', related_name='user_set', to='auth.Group', blank=True,
-                                        help_text='The groups this user belongs to. A user will get all permissions granted to each of his/her group.',
-                                        verbose_name='groups')),
-                ('user_permissions',
-                 models.ManyToManyField(related_query_name='user', related_name='user_set', to='auth.Permission',
-                                        blank=True, help_text='Specific permissions for this user.',
-                                        verbose_name='user permissions')),
+                (
+                    'groups',
+                    models.ManyToManyField(
+                        related_query_name='user',
+                        related_name='user_set',
+                        to='auth.Group',
+                        blank=True,
+                        help_text=
+                        'The groups this user belongs to. A user will get all permissions granted to each of his/her group.',
+                        verbose_name='groups'
+                    )
+                ),
+                (
+                    'user_permissions',
+                    models.ManyToManyField(
+                        related_query_name='user',
+                        related_name='user_set',
+                        to='auth.Permission',
+                        blank=True,
+                        help_text='Specific permissions for this user.',
+                        verbose_name='user permissions'
+                    )
+                ),
             ],
             options={
                 'abstract': False,
@@ -65,11 +92,17 @@ class Migration(migrations.Migration):
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                 ('key', models.CharField(max_length=1024, db_index=True)),
-                ('datatype', models.CharField(default=b'none', max_length=10, db_index=True,
-                                              choices=[(b'float', b'float'), (b'int', b'int'), (b'txt', b'txt'),
-                                                       (b'bool', b'bool'), (b'date', b'date'), (b'json', b'json'),
-                                                       (b'dict', b'dict'), (b'list', b'list'), (b'none', b'none')])),
-                ('tval', models.TextField(default=b'', blank=True)),
+                (
+                    'datatype',
+                    models.CharField(
+                        default='none',
+                        max_length=10,
+                        db_index=True,
+                        choices=[('float', 'float'), ('int', 'int'), ('txt', 'txt'), ('bool', 'bool'), ('date', 'date'),
+                                 ('json', 'json'), ('dict', 'dict'), ('list', 'list'), ('none', 'none')]
+                    )
+                ),
+                ('tval', models.TextField(default='', blank=True)),
                 ('fval', models.FloatField(default=None, null=True)),
                 ('ival', models.IntegerField(default=None, null=True)),
                 ('bval', models.NullBooleanField(default=None)),
@@ -84,64 +117,63 @@ class Migration(migrations.Migration):
             name='DbAuthInfo',
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
-                ('auth_params', models.TextField(default=b'{}')),
-                ('metadata', models.TextField(default=b'{}')),
+                ('auth_params', models.TextField(default='{}')),
+                ('metadata', models.TextField(default='{}')),
                 ('enabled', models.BooleanField(default=True)),
-                ('aiidauser', models.ForeignKey(to=settings.AUTH_USER_MODEL)),
+                ('aiidauser', models.ForeignKey(to='db.DbUser', on_delete=models.CASCADE)),
             ],
-            options={
-            },
+            options={},
             bases=(models.Model,),
         ),
         migrations.CreateModel(
             name='DbCalcState',
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
-                ('state', models.CharField(db_index=True, max_length=25,
-                                           choices=[(b'UNDETERMINED', b'UNDETERMINED'), (b'NOTFOUND', b'NOTFOUND'),
-                                                    (b'RETRIEVALFAILED', b'RETRIEVALFAILED'),
-                                                    (b'COMPUTED', b'COMPUTED'), (b'RETRIEVING', b'RETRIEVING'),
-                                                    (b'WITHSCHEDULER', b'WITHSCHEDULER'),
-                                                    (b'SUBMISSIONFAILED', b'SUBMISSIONFAILED'),
-                                                    (b'PARSING', b'PARSING'), (b'FAILED', b'FAILED'),
-                                                    (b'FINISHED', b'FINISHED'), (b'TOSUBMIT', b'TOSUBMIT'),
-                                                    (b'SUBMITTING', b'SUBMITTING'), (b'IMPORTED', b'IMPORTED'),
-                                                    (b'NEW', b'NEW'), (b'PARSINGFAILED', b'PARSINGFAILED')])),
+                (
+                    'state',
+                    models.CharField(
+                        db_index=True,
+                        max_length=25,
+                        choices=[('UNDETERMINED', 'UNDETERMINED'), ('NOTFOUND', 'NOTFOUND'),
+                                 ('RETRIEVALFAILED', 'RETRIEVALFAILED'), ('COMPUTED', 'COMPUTED'),
+                                 ('RETRIEVING', 'RETRIEVING'), ('WITHSCHEDULER', 'WITHSCHEDULER'),
+                                 ('SUBMISSIONFAILED', 'SUBMISSIONFAILED'), ('PARSING', 'PARSING'), ('FAILED', 'FAILED'),
+                                 ('FINISHED', 'FINISHED'), ('TOSUBMIT', 'TOSUBMIT'), ('SUBMITTING', 'SUBMITTING'),
+                                 ('IMPORTED', 'IMPORTED'), ('NEW', 'NEW'), ('PARSINGFAILED', 'PARSINGFAILED')]
+                    )
+                ),
                 ('time', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
             ],
-            options={
-            },
+            options={},
             bases=(models.Model,),
         ),
         migrations.CreateModel(
             name='DbComment',
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
-                ('uuid', django_extensions.db.fields.UUIDField(editable=False, blank=True)),
+                ('uuid', models.CharField(editable=False, blank=True, max_length=36)),
                 ('ctime', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                 ('mtime', models.DateTimeField(auto_now=True)),
                 ('content', models.TextField(blank=True)),
             ],
-            options={
-            },
+            options={},
             bases=(models.Model,),
         ),
         migrations.CreateModel(
             name='DbComputer',
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
-                ('uuid', django_extensions.db.fields.UUIDField(editable=False, blank=True)),
+                ('uuid', models.CharField(max_length=36, editable=False, blank=True)),
                 ('name', models.CharField(unique=True, max_length=255)),
                 ('hostname', models.CharField(max_length=255)),
                 ('description', models.TextField(blank=True)),
                 ('enabled', models.BooleanField(default=True)),
                 ('transport_type', models.CharField(max_length=255)),
                 ('scheduler_type', models.CharField(max_length=255)),
-                ('transport_params', models.TextField(default=b'{}')),
-                ('metadata', models.TextField(default=b'{}')),
+                ('transport_params', models.TextField(default='{}')),
+                ('metadata', models.TextField(default='{}')),
             ],
-            options={
-            },
+            options={},
             bases=(models.Model,),
         ),
         migrations.CreateModel(
@@ -149,11 +181,17 @@ class Migration(migrations.Migration):
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                 ('key', models.CharField(max_length=1024, db_index=True)),
-                ('datatype', models.CharField(default=b'none', max_length=10, db_index=True,
-                                              choices=[(b'float', b'float'), (b'int', b'int'), (b'txt', b'txt'),
-                                                       (b'bool', b'bool'), (b'date', b'date'), (b'json', b'json'),
-                                                       (b'dict', b'dict'), (b'list', b'list'), (b'none', b'none')])),
-                ('tval', models.TextField(default=b'', blank=True)),
+                (
+                    'datatype',
+                    models.CharField(
+                        default='none',
+                        max_length=10,
+                        db_index=True,
+                        choices=[('float', 'float'), ('int', 'int'), ('txt', 'txt'), ('bool', 'bool'), ('date', 'date'),
+                                 ('json', 'json'), ('dict', 'dict'), ('list', 'list'), ('none', 'none')]
+                    )
+                ),
+                ('tval', models.TextField(default='', blank=True)),
                 ('fval', models.FloatField(default=None, null=True)),
                 ('ival', models.IntegerField(default=None, null=True)),
                 ('bval', models.NullBooleanField(default=None)),
@@ -168,14 +206,13 @@ class Migration(migrations.Migration):
             name='DbGroup',
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
-                ('uuid', django_extensions.db.fields.UUIDField(editable=False, blank=True)),
+                ('uuid', models.CharField(max_length=36, editable=False, blank=True)),
                 ('name', models.CharField(max_length=255, db_index=True)),
-                ('type', models.CharField(default=b'', max_length=255, db_index=True)),
+                ('type', models.CharField(default='', max_length=255, db_index=True)),
                 ('time', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                 ('description', models.TextField(blank=True)),
             ],
-            options={
-            },
+            options={},
             bases=(models.Model,),
         ),
         migrations.CreateModel(
@@ -184,8 +221,7 @@ class Migration(migrations.Migration):
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                 ('label', models.CharField(max_length=255, db_index=True)),
             ],
-            options={
-            },
+            options={},
             bases=(models.Model,),
         ),
         migrations.CreateModel(
@@ -196,8 +232,7 @@ class Migration(migrations.Migration):
                 ('timeout', models.IntegerField(editable=False)),
                 ('owner', models.CharField(max_length=255)),
             ],
-            options={
-            },
+            options={},
             bases=(models.Model,),
         ),
         migrations.CreateModel(
@@ -210,17 +245,16 @@ class Migration(migrations.Migration):
                 ('objname', models.CharField(db_index=True, max_length=255, blank=True)),
                 ('objpk', models.IntegerField(null=True, db_index=True)),
                 ('message', models.TextField(blank=True)),
-                ('metadata', models.TextField(default=b'{}')),
+                ('metadata', models.TextField(default='{}')),
             ],
-            options={
-            },
+            options={},
             bases=(models.Model,),
         ),
         migrations.CreateModel(
             name='DbNode',
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
-                ('uuid', django_extensions.db.fields.UUIDField(editable=False, blank=True)),
+                ('uuid', models.CharField(max_length=36, editable=False, blank=True)),
                 ('type', models.CharField(max_length=255, db_index=True)),
                 ('label', models.CharField(db_index=True, max_length=255, blank=True)),
                 ('description', models.TextField(blank=True)),
@@ -229,8 +263,7 @@ class Migration(migrations.Migration):
                 ('nodeversion', models.IntegerField(default=1, editable=False)),
                 ('public', models.BooleanField(default=False)),
             ],
-            options={
-            },
+            options={},
             bases=(models.Model,),
         ),
         migrations.CreateModel(
@@ -241,11 +274,20 @@ class Migration(migrations.Migration):
                 ('entry_edge_id', models.IntegerField(null=True, editable=False)),
                 ('direct_edge_id', models.IntegerField(null=True, editable=False)),
                 ('exit_edge_id', models.IntegerField(null=True, editable=False)),
-                ('child', models.ForeignKey(related_name='parent_paths', editable=False, to='db.DbNode')),
-                ('parent', models.ForeignKey(related_name='child_paths', editable=False, to='db.DbNode')),
+                (
+                    'child',
+                    models.ForeignKey(
+                        related_name='parent_paths', editable=False, to='db.DbNode', on_delete=models.CASCADE
+                    )
+                ),
+                (
+                    'parent',
+                    models.ForeignKey(
+                        related_name='child_paths', editable=False, to='db.DbNode', on_delete=models.CASCADE
+                    )
+                ),
             ],
-            options={
-            },
+            options={},
             bases=(models.Model,),
         ),
         migrations.CreateModel(
@@ -253,11 +295,17 @@ class Migration(migrations.Migration):
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                 ('key', models.CharField(max_length=1024, db_index=True)),
-                ('datatype', models.CharField(default=b'none', max_length=10, db_index=True,
-                                              choices=[(b'float', b'float'), (b'int', b'int'), (b'txt', b'txt'),
-                                                       (b'bool', b'bool'), (b'date', b'date'), (b'json', b'json'),
-                                                       (b'dict', b'dict'), (b'list', b'list'), (b'none', b'none')])),
-                ('tval', models.TextField(default=b'', blank=True)),
+                (
+                    'datatype',
+                    models.CharField(
+                        default='none',
+                        max_length=10,
+                        db_index=True,
+                        choices=[('float', 'float'), ('int', 'int'), ('txt', 'txt'), ('bool', 'bool'), ('date', 'date'),
+                                 ('json', 'json'), ('dict', 'dict'), ('list', 'list'), ('none', 'none')]
+                    )
+                ),
+                ('tval', models.TextField(default='', blank=True)),
                 ('fval', models.FloatField(default=None, null=True)),
                 ('ival', models.IntegerField(default=None, null=True)),
                 ('bval', models.NullBooleanField(default=None)),
@@ -274,26 +322,30 @@ class Migration(migrations.Migration):
             name='DbWorkflow',
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
-                ('uuid', django_extensions.db.fields.UUIDField(editable=False, blank=True)),
+                ('uuid', models.CharField(max_length=36, editable=False, blank=True)),
                 ('ctime', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                 ('mtime', models.DateTimeField(auto_now=True)),
                 ('label', models.CharField(db_index=True, max_length=255, blank=True)),
                 ('description', models.TextField(blank=True)),
                 ('nodeversion', models.IntegerField(default=1, editable=False)),
                 ('lastsyncedversion', models.IntegerField(default=0, editable=False)),
-                ('state', models.CharField(default=b'INITIALIZED', max_length=255,
-                                           choices=[(b'CREATED', b'CREATED'), (b'FINISHED', b'FINISHED'),
-                                                    (b'RUNNING', b'RUNNING'), (b'SLEEP', b'SLEEP'),
-                                                    (b'ERROR', b'ERROR'), (b'INITIALIZED', b'INITIALIZED')])),
+                (
+                    'state',
+                    models.CharField(
+                        choices=[('CREATED', 'CREATED'), ('ERROR', 'ERROR'), ('FINISHED', 'FINISHED'),
+                                 ('INITIALIZED', 'INITIALIZED'), ('RUNNING', 'RUNNING'), ('SLEEP', 'SLEEP')],
+                        default='INITIALIZED',
+                        max_length=255
+                    )
+                ),
                 ('report', models.TextField(blank=True)),
                 ('module', models.TextField()),
                 ('module_class', models.TextField()),
                 ('script_path', models.TextField()),
                 ('script_md5', models.CharField(max_length=255)),
-                ('user', models.ForeignKey(to=settings.AUTH_USER_MODEL, on_delete=django.db.models.deletion.PROTECT)),
+                ('user', models.ForeignKey(to='db.DbUser', on_delete=django.db.models.deletion.PROTECT)),
             ],
-            options={
-            },
+            options={},
             bases=(models.Model,),
         ),
         migrations.CreateModel(
@@ -302,14 +354,13 @@ class Migration(migrations.Migration):
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                 ('name', models.CharField(max_length=255)),
                 ('time', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
-                ('data_type', models.CharField(default=b'PARAMETER', max_length=255)),
-                ('value_type', models.CharField(default=b'NONE', max_length=255)),
+                ('data_type', models.CharField(default='PARAMETER', max_length=255)),
+                ('value_type', models.CharField(default='NONE', max_length=255)),
                 ('json_value', models.TextField(blank=True)),
-                ('aiida_obj', models.ForeignKey(blank=True, to='db.DbNode', null=True)),
-                ('parent', models.ForeignKey(related_name='data', to='db.DbWorkflow')),
+                ('aiida_obj', models.ForeignKey(blank=True, to='db.DbNode', null=True, on_delete=models.CASCADE)),
+                ('parent', models.ForeignKey(related_name='data', to='db.DbWorkflow', on_delete=models.CASCADE)),
             ],
-            options={
-            },
+            options={},
             bases=(models.Model,),
         ),
         migrations.CreateModel(
@@ -318,18 +369,22 @@ class Migration(migrations.Migration):
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                 ('name', models.CharField(max_length=255)),
                 ('time', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
-                ('nextcall', models.CharField(default=b'none', max_length=255)),
-                ('state', models.CharField(default=b'CREATED', max_length=255,
-                                           choices=[(b'CREATED', b'CREATED'), (b'FINISHED', b'FINISHED'),
-                                                    (b'RUNNING', b'RUNNING'), (b'SLEEP', b'SLEEP'),
-                                                    (b'ERROR', b'ERROR'), (b'INITIALIZED', b'INITIALIZED')])),
+                ('nextcall', models.CharField(default='none', max_length=255)),
+                (
+                    'state',
+                    models.CharField(
+                        choices=[('CREATED', 'CREATED'), ('ERROR', 'ERROR'), ('FINISHED', 'FINISHED'),
+                                 ('INITIALIZED', 'INITIALIZED'), ('RUNNING', 'RUNNING'), ('SLEEP', 'SLEEP')],
+                        default='CREATED',
+                        max_length=255
+                    )
+                ),
                 ('calculations', models.ManyToManyField(related_name='workflow_step', to='db.DbNode')),
-                ('parent', models.ForeignKey(related_name='steps', to='db.DbWorkflow')),
+                ('parent', models.ForeignKey(related_name='steps', to='db.DbWorkflow', on_delete=models.CASCADE)),
                 ('sub_workflows', models.ManyToManyField(related_name='parent_workflow_step', to='db.DbWorkflow')),
-                ('user', models.ForeignKey(to=settings.AUTH_USER_MODEL, on_delete=django.db.models.deletion.PROTECT)),
+                ('user', models.ForeignKey(to='db.DbUser', on_delete=django.db.models.deletion.PROTECT)),
             ],
-            options={
-            },
+            options={},
             bases=(models.Model,),
         ),
         migrations.AlterUniqueTogether(
@@ -353,8 +408,9 @@ class Migration(migrations.Migration):
         migrations.AddField(
             model_name='dbnode',
             name='dbcomputer',
-            field=models.ForeignKey(related_name='dbnodes', on_delete=django.db.models.deletion.PROTECT,
-                                    to='db.DbComputer', null=True),
+            field=models.ForeignKey(
+                related_name='dbnodes', on_delete=django.db.models.deletion.PROTECT, to='db.DbComputer', null=True
+            ),
             preserve_default=True,
         ),
         migrations.AddField(
@@ -366,21 +422,23 @@ class Migration(migrations.Migration):
         migrations.AddField(
             model_name='dbnode',
             name='user',
-            field=models.ForeignKey(related_name='dbnodes', on_delete=django.db.models.deletion.PROTECT,
-                                    to=settings.AUTH_USER_MODEL),
+            field=models.ForeignKey(
+                related_name='dbnodes', on_delete=django.db.models.deletion.PROTECT, to='db.DbUser'
+            ),
             preserve_default=True,
         ),
         migrations.AddField(
             model_name='dblink',
             name='input',
-            field=models.ForeignKey(related_name='output_links', on_delete=django.db.models.deletion.PROTECT,
-                                    to='db.DbNode'),
+            field=models.ForeignKey(
+                related_name='output_links', on_delete=django.db.models.deletion.PROTECT, to='db.DbNode'
+            ),
             preserve_default=True,
         ),
         migrations.AddField(
             model_name='dblink',
             name='output',
-            field=models.ForeignKey(related_name='input_links', to='db.DbNode'),
+            field=models.ForeignKey(related_name='input_links', to='db.DbNode', on_delete=models.CASCADE),
             preserve_default=True,
         ),
         migrations.AlterUniqueTogether(
@@ -396,7 +454,7 @@ class Migration(migrations.Migration):
         migrations.AddField(
             model_name='dbgroup',
             name='user',
-            field=models.ForeignKey(related_name='dbgroups', to=settings.AUTH_USER_MODEL),
+            field=models.ForeignKey(related_name='dbgroups', to='db.DbUser', on_delete=models.CASCADE),
             preserve_default=True,
         ),
         migrations.AlterUniqueTogether(
@@ -406,7 +464,7 @@ class Migration(migrations.Migration):
         migrations.AddField(
             model_name='dbextra',
             name='dbnode',
-            field=models.ForeignKey(related_name='dbextras', to='db.DbNode'),
+            field=models.ForeignKey(related_name='dbextras', to='db.DbNode', on_delete=models.CASCADE),
             preserve_default=True,
         ),
         migrations.AlterUniqueTogether(
@@ -416,19 +474,19 @@ class Migration(migrations.Migration):
         migrations.AddField(
             model_name='dbcomment',
             name='dbnode',
-            field=models.ForeignKey(related_name='dbcomments', to='db.DbNode'),
+            field=models.ForeignKey(related_name='dbcomments', to='db.DbNode', on_delete=models.CASCADE),
             preserve_default=True,
         ),
         migrations.AddField(
             model_name='dbcomment',
             name='user',
-            field=models.ForeignKey(to=settings.AUTH_USER_MODEL),
+            field=models.ForeignKey(to='db.DbUser', on_delete=models.CASCADE),
             preserve_default=True,
         ),
         migrations.AddField(
             model_name='dbcalcstate',
             name='dbnode',
-            field=models.ForeignKey(related_name='dbstates', to='db.DbNode'),
+            field=models.ForeignKey(related_name='dbstates', to='db.DbNode', on_delete=models.CASCADE),
             preserve_default=True,
         ),
         migrations.AlterUniqueTogether(
@@ -438,7 +496,7 @@ class Migration(migrations.Migration):
         migrations.AddField(
             model_name='dbauthinfo',
             name='dbcomputer',
-            field=models.ForeignKey(to='db.DbComputer'),
+            field=models.ForeignKey(to='db.DbComputer', on_delete=models.CASCADE),
             preserve_default=True,
         ),
         migrations.AlterUniqueTogether(
@@ -448,12 +506,12 @@ class Migration(migrations.Migration):
         migrations.AddField(
             model_name='dbattribute',
             name='dbnode',
-            field=models.ForeignKey(related_name='dbattributes', to='db.DbNode'),
+            field=models.ForeignKey(related_name='dbattributes', to='db.DbNode', on_delete=models.CASCADE),
             preserve_default=True,
         ),
         migrations.AlterUniqueTogether(
             name='dbattribute',
             unique_together=set([('dbnode', 'key')]),
         ),
-        update_schema_version(SCHEMA_VERSION)
+        upgrade_schema_version(REVISION, DOWN_REVISION)
     ]
