@@ -3,19 +3,19 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
-from __future__ import unicode_literals
 
-import django_extensions.db.fields
+from django.db import models
 from django.db import migrations
 
-from aiida.backends.djsite.db.migrations import update_schema_version
+from aiida.backends.djsite.db.migrations import upgrade_schema_version
 
 
-SCHEMA_VERSION = "1.0.4"
+REVISION = '1.0.4'
+DOWN_REVISION = '1.0.3'
 
 
 class Migration(migrations.Migration):
@@ -38,10 +38,10 @@ class Migration(migrations.Migration):
         migrations.AlterField(
             model_name='dbnode',
             name='uuid',
-            field=django_extensions.db.fields.UUIDField(db_index=True,
+            field=models.CharField(max_length=36,db_index=True,
                                                         editable=False,
                                                         blank=True),
             preserve_default=True,
         ),
-        update_schema_version(SCHEMA_VERSION)
+        upgrade_schema_version(REVISION, DOWN_REVISION)
     ]
