@@ -3,18 +3,18 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
-from __future__ import unicode_literals
 
 from django.db import models, migrations
-import aiida.utils.timezone
-from aiida.backends.djsite.db.migrations import update_schema_version
+import aiida.common.timezone
+from aiida.backends.djsite.db.migrations import upgrade_schema_version
 
 
-SCHEMA_VERSION = "1.0.5"
+REVISION = '1.0.5'
+DOWN_REVISION = '1.0.4'
 
 
 class Migration(migrations.Migration):
@@ -27,7 +27,7 @@ class Migration(migrations.Migration):
         migrations.AlterField(
             model_name='dbnode',
             name='ctime',
-            field=models.DateTimeField(default=aiida.utils.timezone.now, editable=False, db_index=True),
+            field=models.DateTimeField(default=aiida.common.timezone.now, editable=False, db_index=True),
             preserve_default=True,
         ),
         migrations.AlterField(
@@ -36,5 +36,5 @@ class Migration(migrations.Migration):
             field=models.DateTimeField(auto_now=True, db_index=True),
             preserve_default=True,
         ),
-        update_schema_version(SCHEMA_VERSION)
+        upgrade_schema_version(REVISION, DOWN_REVISION)
     ]
