@@ -25,8 +25,11 @@ from aiida.cmdline.utils.daemon import get_daemon_status, \
 from aiida.manage.configuration import get_config
 
 
-def validate_positive_non_zero_integer(ctx, param, value):  # pylint: disable=unused-argument,invalid-name
-    """Validate that `value` is a positive integer."""
+def validate_daemon_workers(ctx, param, value):  # pylint: disable=unused-argument,invalid-name
+    """Validate the value for the number of daemon workers to start with default set by config."""
+    if value is None:
+        value = ctx.obj.config.get_option('daemon.default_workers', ctx.obj.profile.name)
+
     if not isinstance(value, int):
         raise click.BadParameter('{} is not an integer'.format(value))
 
@@ -43,11 +46,15 @@ def verdi_daemon():
 
 @verdi_daemon.command()
 @click.option('--foreground', is_flag=True, help='Run in foreground.')
-@click.argument('number', default=1, type=int, callback=validate_positive_non_zero_integer)
+@click.argument('number', required=False, type=int, callback=validate_daemon_workers)
 @decorators.with_dbenv()
 @decorators.check_circus_zmq_version
 def start(foreground, number):
-    """Start the daemon with NUMBER workers [default=1]."""
+    """Start the daemon with NUMBER workers.
+
+    If the NUMBER of desired workers is not specified, the default is used, which is determined by the configuration
+    option `daemon.default_workers`, which if not explicitly changed defaults to 1.
+    """
     from aiida.engine.daemon.client import get_daemon_client
 
     client = get_daemon_client()
@@ -196,8 +203,8 @@ def restart(ctx, reset, no_wait):
     """Restart the daemon.
 
     By default will only reset the workers of the running daemon. After the restart the same amount of workers will be
-    running. If the `--reset` flag is passed, however, the full circus daemon will be stopped and restarted with just
-    a single worker.
+    running. If the `--reset` flag is passed, however, the full daemon will be stopped and restarted with the default
+    number of workers that is started when calling `verdi daemon start` manually.
     """
     from aiida.engine.daemon.client import get_daemon_client
 
@@ -223,7 +230,7 @@ def restart(ctx, reset, no_wait):
 
 @verdi_daemon.command(hidden=True)
 @click.option('--foreground', is_flag=True, help='Run in foreground.')
-@click.argument('number', default=1, type=int, callback=validate_positive_non_zero_integer)
+@click.argument('number', required=False, type=int, callback=validate_daemon_workers)
 @decorators.with_dbenv()
 @decorators.check_circus_zmq_version
 def start_circus(foreground, number):
