@@ -3,8 +3,22 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
-from aiida.common.log import aiidalogger
\ No newline at end of file
+# pylint: disable=wildcard-import,undefined-variable
+"""
+Common data structures, utility classes and functions
+
+.. note:: Modules in this sub package have to run without a loaded database environment
+
+"""
+
+from .datastructures import *
+from .exceptions import *
+from .extendeddicts import *
+from .links import *
+from .log import *
+
+__all__ = (datastructures.__all__ + exceptions.__all__ + extendeddicts.__all__ + links.__all__ + log.__all__)
