@@ -3,11 +3,22 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
+"""Module that define the exceptions that are thrown by AiiDA's internal code."""
 
+__all__ = (
+    'AiidaException', 'NotExistent', 'MultipleObjectsError', 'RemoteOperationError', 'ContentNotExistent',
+    'FailedError', 'StoringNotAllowed', 'ModificationNotAllowed', 'IntegrityError', 'UniquenessError',
+    'EntryPointError', 'MissingEntryPointError', 'MultipleEntryPointError', 'LoadingEntryPointError',
+    'InvalidEntryPointTypeError', 'InvalidOperation', 'ParsingError', 'InternalError', 'PluginInternalError',
+    'ValidationError', 'ConfigurationError', 'ProfileConfigurationError', 'MissingConfigurationError',
+    'ConfigurationVersionError', 'IncompatibleDatabaseSchema', 'DbContentError', 'InputValidationError',
+    'FeatureNotAvailable', 'FeatureDisabled', 'LicensingException', 'TestsNotAllowedError', 'UnsupportedSpeciesError',
+    'TransportTaskException', 'OutputParsingError'
+)
 
 
 class AiidaException(Exception):
@@ -17,14 +28,12 @@ class AiidaException(Exception):
     Each module will have its own subclass, inherited from this
     (e.g. ExecManagerException, TransportException, ...)
     """
-    pass
 
 
 class NotExistent(AiidaException):
     """
     Raised when the required entity does not exist.
     """
-    pass
 
 
 class MultipleObjectsError(AiidaException):
@@ -32,7 +41,6 @@ class MultipleObjectsError(AiidaException):
     Raised when more than one entity is found in the DB, but only one was
     expected.
     """
-    pass
 
 
 class RemoteOperationError(AiidaException):
@@ -40,7 +48,6 @@ class RemoteOperationError(AiidaException):
     Raised when an error in a remote operation occurs, as in a failed kill()
     of a scheduler job.
     """
-    pass
 
 
 class ContentNotExistent(NotExistent):
@@ -48,14 +55,18 @@ class ContentNotExistent(NotExistent):
     Raised when trying to access an attribute, a key or a file in the result
     nodes that is not present
     """
-    pass
 
 
 class FailedError(AiidaException):
     """
     Raised when accessing a calculation that is in the FAILED status
     """
-    pass
+
+
+class StoringNotAllowed(AiidaException):
+    """
+    Raised when the user tries to store an unstorable node (e.g. a base Node class)
+    """
 
 
 class ModificationNotAllowed(AiidaException):
@@ -63,7 +74,14 @@ class ModificationNotAllowed(AiidaException):
     Raised when the user tries to modify a field, object, property, ... that should not
     be modified.
     """
-    pass
+
+
+class IntegrityError(AiidaException):
+    """
+    Raised when there is an underlying data integrity error.  This can be database related
+    or a general data integrity error.  This can happen if, e.g., a foreign key check fails.
+    See PEP 249 for details.
+    """
 
 
 class UniquenessError(AiidaException):
@@ -71,21 +89,26 @@ class UniquenessError(AiidaException):
     Raised when the user tries to violate a uniqueness constraint (on the
     DB, for instance).
     """
-    pass
 
 
-class MissingPluginError(AiidaException):
-    """
-    Raised when the user tries to use a plugin that is not available or does not exist.
-    """
-    pass
+class EntryPointError(AiidaException):
+    """Raised when an entry point cannot be uniquely resolved and imported."""
 
 
-class LoadingPluginFailed(AiidaException):
-    """
-    Raised when loading a plugin through the plugin loader fails
-    """
-    pass
+class MissingEntryPointError(EntryPointError):
+    """Raised when the requested entry point is not registered with the entry point manager."""
+
+
+class MultipleEntryPointError(EntryPointError):
+    """Raised when the requested entry point cannot uniquely be resolved by the entry point manager."""
+
+
+class LoadingEntryPointError(EntryPointError):
+    """Raised when the resource corresponding to requested entry point cannot be imported."""
+
+
+class InvalidEntryPointTypeError(EntryPointError):
+    """Raised when a loaded entry point has a type that is not supported by the corresponding entry point group."""
 
 
 class InvalidOperation(AiidaException):
@@ -94,21 +117,18 @@ class InvalidOperation(AiidaException):
     before saving the entry), or deleting an entry that is protected (e.g.,
     because it is referenced by foreign keys)
     """
-    pass
 
 
 class ParsingError(AiidaException):
     """
     Generic error raised when there is a parsing error
     """
-    pass
 
 
 class InternalError(AiidaException):
     """
     Error raised when there is an internal error of AiiDA.
     """
-    pass
 
 
 class PluginInternalError(InternalError):
@@ -116,7 +136,6 @@ class PluginInternalError(InternalError):
     Error raised when there is an internal error which is due to a plugin
     and not to the AiiDA infrastructure.
     """
-    pass
 
 
 class ValidationError(AiidaException):
@@ -124,33 +143,36 @@ class ValidationError(AiidaException):
     Error raised when there is an error during the validation phase
     of a property.
     """
-    pass
 
 
 class ConfigurationError(AiidaException):
     """
     Error raised when there is a configuration error in AiiDA.
     """
-    pass
+
 
 class ProfileConfigurationError(ConfigurationError):
     """
     Configuration error raised when a wrong/inexistent profile is requested.
     """
-    pass
+
 
 class MissingConfigurationError(ConfigurationError):
     """
     Configuration error raised when the configuration file is missing.
     """
-    pass
+
 
 class ConfigurationVersionError(ConfigurationError):
     """
     Configuration error raised when the configuration file version is not
     compatible with the current version.
     """
-    pass
+
+
+class IncompatibleDatabaseSchema(ConfigurationError):
+    """Raised when the database schema is incompatible with that of the code."""
+
 
 class DbContentError(AiidaException):
     """
@@ -158,16 +180,6 @@ class DbContentError(AiidaException):
     This should never happen if the user does not play directly
     with the DB.
     """
-    pass
-
-
-class AuthenticationError(AiidaException):
-    """
-    Raised when a user tries to access a resource for which it is
-    not authenticated, e.g. an aiidauser tries to access a computer
-    for which there is no entry in the AuthInfo table.
-    """
-    pass
 
 
 class InputValidationError(ValidationError):
@@ -175,22 +187,12 @@ class InputValidationError(ValidationError):
     The input data for a calculation did not validate (e.g., missing
     required input data, wrong data, ...)
     """
-    pass
-
-
-class WorkflowInputValidationError(ValidationError):
-    """
-    The input data for a workflow did not validate (e.g., missing
-    required input data, wrong data, ...)
-    """
-    pass
 
 
 class FeatureNotAvailable(AiidaException):
     """
     Raised when a feature is requested from a plugin, that is not available.
     """
-    pass
 
 
 class FeatureDisabled(AiidaException):
@@ -198,21 +200,13 @@ class FeatureDisabled(AiidaException):
     Raised when a feature is requested, but the user has chosen to disable
     it (e.g., for submissions on disabled computers).
     """
-    pass
-
-
-class LockPresent(AiidaException):
-    """
-    Raised when a lock is requested, but cannot be acquired.
-    """
-    pass
 
 
 class LicensingException(AiidaException):
     """
     Raised when requirements for data licensing are not met.
     """
-    pass
+
 
 class TestsNotAllowedError(AiidaException):
     """
@@ -220,4 +214,27 @@ class TestsNotAllowedError(AiidaException):
 
     This is to prevent data loss.
     """
-    pass
+
+
+class UnsupportedSpeciesError(ValueError):
+    """
+    Raised when StructureData operations are fed species that are not supported by AiiDA such as Deuterium
+    """
+
+
+class TransportTaskException(AiidaException):
+    """
+    Raised when a TransportTask, an task to be completed by the engine that requires transport, fails
+    """
+
+
+class OutputParsingError(ParsingError):
+    """
+    Can be raised by a Parser when it fails to parse the output generated by a `CalcJob` process.
+    """
+
+
+class CircusCallError(AiidaException):
+    """
+    Raised when an attempt to contact Circus returns an error in the response
+    """
