@@ -3,17 +3,15 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
-from __future__ import absolute_import
-from builtins import zip
-from aiida.orm.data.array.kpoints import KpointsData
-from aiida.orm.data.parameter import ParameterData
-from aiida.tools.data.structure import spglib_tuple_to_structure, structure_to_spglib_tuple
 
-__all__ = ['check_seekpath_is_installed', 'get_explicit_kpoints_path', 'get_kpoints_path']
+from aiida.orm import KpointsData, Dict
+
+__all__ = ('check_seekpath_is_installed', 'get_explicit_kpoints_path', 'get_kpoints_path')
+
 
 def check_seekpath_is_installed():
     """
@@ -26,9 +24,10 @@ def check_seekpath_is_installed():
     except ImportError:
         raise ImportError("Seekpath is not installed, please install with 'pip install seekpath'")
 
+
 def get_explicit_kpoints_path(structure, parameters):
     """
-    Return the kpoint path for band structure (in scaled and absolute 
+    Return the kpoint path for band structure (in scaled and absolute
     coordinates), given a crystal structure,
     using the paths proposed in the various publications (see description
     of the 'recipe' input parameter). The parameters are the same
@@ -37,7 +36,7 @@ def get_explicit_kpoints_path(structure, parameters):
     k-points-related information as a AiiDA KpointsData class.
 
     :param structure: The AiiDA StructureData for which we want to obtain
-        the suggested path. 
+        the suggested path.
 
     :param parameters: A dictionary whose key-value pairs are passed as
         additional kwargs to the ``seekpath.get_explicit_k_path`` function.
@@ -47,7 +46,7 @@ def get_explicit_kpoints_path(structure, parameters):
         - ``explicit_kpoints``: a KpointsData with the (explicit) kpoints
           (with labels set).
 
-        - ``parameters``: a ParameterData, whose content is
+        - ``parameters``: a Dict, whose content is
           the same dictionary as returned by the ``seekpath.get_explicit_k_path`` function
           (see `seekpath documentation <https://seekpath.readthedocs.io/>`_),
           except that:
@@ -58,7 +57,7 @@ def get_explicit_kpoints_path(structure, parameters):
           - ``primitive_lattice``, ``primitive_positions``, ``primitive_types``
             are removed and replaced by the `primitive_structure` output node
 
-          - ``reciprocal_primitive_lattice``, ``explicit_kpoints_abs``,  
+          - ``reciprocal_primitive_lattice``, ``explicit_kpoints_abs``,
             ``explicit_kpoints_rel`` and ``explicit_kpoints_labels`` are removed
             and replaced by the ``explicit_kpoints`` output node
 
@@ -66,6 +65,8 @@ def get_explicit_kpoints_path(structure, parameters):
 
         - ``conv_structure``: A StructureData with the primitive structure
     """
+    from aiida.tools.data.structure import spglib_tuple_to_structure, structure_to_spglib_tuple
+
     check_seekpath_is_installed()
     import seekpath
 
@@ -100,23 +101,24 @@ def get_explicit_kpoints_path(structure, parameters):
     kpoints.set_cell_from_structure(primitive_structure)
     kpoints.set_kpoints(kpoints_abs, cartesian=True, labels=labels)
 
-    result['parameters'] = ParameterData(dict=rawdict)
+    result['parameters'] = Dict(dict=rawdict)
     result['explicit_kpoints'] = kpoints
     result['primitive_structure'] = primitive_structure
     result['conv_structure'] = conv_structure
 
     return result
 
+
 def get_kpoints_path(structure, parameters):
     """
-    Return the kpoint path information for band structure given a 
+    Return the kpoint path information for band structure given a
     crystal structure, using the paths from the chosen recipe/reference.
     The parameters are the same
     as get get_path in __init__, but here all structures are
     input and returned as AiiDA structures rather than tuples.
 
 
-    If you use this module, please cite the paper of the corresponding 
+    If you use this module, please cite the paper of the corresponding
     recipe (see documentation of seekpath).
 
     :param structure: The crystal structure for which we want to obtain
@@ -127,7 +129,7 @@ def get_kpoints_path(structure, parameters):
 
     :return: A dictionary with three nodes:
 
-        - ``parameters``: a ParameterData, whose content is
+        - ``parameters``: a Dict, whose content is
           the same dictionary as returned by the ``seekpath.get_path`` function
           (see `seekpath documentation <https://seekpath.readthedocs.io/>`_),
           except that:
@@ -142,6 +144,8 @@ def get_kpoints_path(structure, parameters):
 
         - ``conv_structure``: A StructureData with the primitive structure
     """
+    from aiida.tools.data.structure import spglib_tuple_to_structure, structure_to_spglib_tuple
+
     check_seekpath_is_installed()
     import seekpath
 
@@ -164,7 +168,7 @@ def get_kpoints_path(structure, parameters):
     primitive_tuple = (primitive_lattice, primitive_positions, primitive_types)
     primitive_structure = spglib_tuple_to_structure(primitive_tuple, kind_info, kinds)
 
-    result['parameters'] = ParameterData(dict=rawdict)
+    result['parameters'] = Dict(dict=rawdict)
     result['primitive_structure'] = primitive_structure
     result['conv_structure'] = conv_structure
 
