@@ -3,7 +3,7 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
@@ -19,28 +19,28 @@ class PcodDbImporter(CodDbImporter):
     """
 
     def _int_clause(self, *args, **kwargs):
-        return super(PcodDbImporter, self)._int_clause(*args, **kwargs)
+        return super()._int_clause(*args, **kwargs)
 
     def _composition_clause(self, *args, **kwargs):
-        return super(PcodDbImporter, self)._composition_clause(*args, **kwargs)
+        return super()._composition_clause(*args, **kwargs)
 
     def _formula_clause(self, *args, **kwargs):
-        return super(PcodDbImporter, self)._formula_clause(*args, **kwargs)
+        return super()._formula_clause(*args, **kwargs)
 
     def _volume_clause(self, *args, **kwargs):
-        return super(PcodDbImporter, self)._volume_clause(*args, **kwargs)
+        return super()._volume_clause(*args, **kwargs)
 
     def _str_exact_clause(self, *args, **kwargs):
-        return super(PcodDbImporter, self)._str_exact_clause(*args, **kwargs)
+        return super()._str_exact_clause(*args, **kwargs)
 
     def _length_clause(self, *args, **kwargs):
-        return super(PcodDbImporter, self)._length_clause(*args, **kwargs)
+        return super()._length_clause(*args, **kwargs)
 
     def _angle_clause(self, *args, **kwargs):
-        return super(PcodDbImporter, self)._angle_clause(*args, **kwargs)
+        return super()._angle_clause(*args, **kwargs)
 
     def _str_fuzzy_clause(self, *args, **kwargs):
-        return super(PcodDbImporter, self)._str_fuzzy_clause(*args, **kwargs)
+        return super()._str_fuzzy_clause(*args, **kwargs)
 
     _keywords = {'id': ['file', _int_clause],
                  'element': ['element', _composition_clause],
@@ -57,7 +57,7 @@ class PcodDbImporter(CodDbImporter):
                  'text': ['text', _str_fuzzy_clause]}
 
     def __init__(self, **kwargs):
-        super(PcodDbImporter, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self._db_parameters = {'host': 'www.crystallography.net',
                                'user': 'pcod_reader',
                                'passwd': '',
@@ -78,18 +78,18 @@ class PcodDbImporter(CodDbImporter):
                 if not isinstance(values, list):
                     values = [values]
                 sql_parts.append( \
-                    "(" + self._keywords[key][1](self, \
+                    '(' + self._keywords[key][1](self, \
                                                  self._keywords[key][0], \
                                                  key, \
                                                  values) + \
-                    ")")
+                    ')')
         if len(kwargs.keys()) > 0:
             raise NotImplementedError( \
                 "search keyword(s) '" + \
                 "', '".join(kwargs.keys()) + "' " + \
-                "is(are) not implemented for PCOD")
-        return "SELECT file FROM data WHERE " + \
-               " AND ".join(sql_parts)
+                'is(are) not implemented for PCOD')
+        return 'SELECT file FROM data WHERE ' + \
+               ' AND '.join(sql_parts)
 
     def query(self, **kwargs):
         """
@@ -117,10 +117,10 @@ class PcodSearchResults(CodSearchResults):
     """
     Results of the search, performed on PCOD.
     """
-    _base_url = "http://www.crystallography.net/pcod/cif/"
+    _base_url = 'http://www.crystallography.net/pcod/cif/'
 
     def __init__(self, results):
-        super(PcodSearchResults, self).__init__(results)
+        super().__init__(results)
         self._return_class = PcodEntry
 
     def _get_url(self, result_dict):
@@ -130,9 +130,9 @@ class PcodSearchResults(CodSearchResults):
         :param result_dict: dictionary, describing an entry in the results.
         """
         return self._base_url + \
-               result_dict['id'][0] + "/" + \
-               result_dict['id'][0:3] + "/" + \
-               result_dict['id'] + ".cif"
+               result_dict['id'][0] + '/' + \
+               result_dict['id'][0:3] + '/' + \
+               result_dict['id'] + '.cif'
 
 
 class PcodEntry(CodEntry):
@@ -149,7 +149,7 @@ class PcodEntry(CodEntry):
         :py:class:`aiida.tools.dbimporters.plugins.pcod.PcodEntry`, related
         to the supplied URI.
         """
-        super(PcodEntry, self).__init__(db_name=db_name,
+        super().__init__(db_name=db_name,
                                         db_uri=db_uri,
                                         uri=uri,
                                         **kwargs)
