@@ -21,10 +21,10 @@ from aiida.common.folders import SandboxFolder, RepositoryFolder
 from aiida.common.links import LinkType, validate_link_label
 from aiida.common.utils import grouper, get_object_from_string
 from aiida.orm.utils.repository import Repository
-from aiida.orm import QueryBuilder, Node, Group
+from aiida.orm import QueryBuilder, Node, Group, ImportGroup
 from aiida.tools.importexport.common import exceptions
 from aiida.tools.importexport.common.archive import extract_tree, extract_tar, extract_zip
-from aiida.tools.importexport.common.config import DUPL_SUFFIX, IMPORTGROUP_TYPE, EXPORT_VERSION, NODES_EXPORT_SUBFOLDER
+from aiida.tools.importexport.common.config import DUPL_SUFFIX, EXPORT_VERSION, NODES_EXPORT_SUBFOLDER
 from aiida.tools.importexport.common.config import (
     NODE_ENTITY_NAME, GROUP_ENTITY_NAME, COMPUTER_ENTITY_NAME, USER_ENTITY_NAME, LOG_ENTITY_NAME, COMMENT_ENTITY_NAME
 )
@@ -673,7 +673,7 @@ def import_data_dj(
                             "Overflow of import groups (more than 100 import groups exists with basename '{}')"
                             ''.format(basename)
                         )
-                group = Group(label=group_label, type_string=IMPORTGROUP_TYPE).store()
+                group = ImportGroup(label=group_label).store()
 
             # Add all the nodes to the new group
             # TODO: decide if we want to return the group label
