@@ -8,9 +8,9 @@
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
 """Migration export files from old export versions to the newest, used by `verdi export migrate` command."""
-
-from aiida.cmdline.utils import echo
-from aiida.tools.importexport.common.exceptions import DanglingLinkError
+from aiida.common.lang import type_check
+from aiida.tools.importexport import EXPORT_VERSION
+from aiida.tools.importexport.common.exceptions import DanglingLinkError, ArchiveMigrationError
 
 from .utils import verify_metadata_version
 from .v01_to_v02 import migrate_v1_to_v2
@@ -20,6 +20,7 @@ from .v04_to_v05 import migrate_v4_to_v5
 from .v05_to_v06 import migrate_v5_to_v6
 from .v06_to_v07 import migrate_v6_to_v7
 from .v07_to_v08 import migrate_v7_to_v8
+from .v08_to_v09 import migrate_v8_to_v9
 
 __all__ = ('migrate_recursively', 'verify_metadata_version')
 
@@ -31,37 +32,41 @@ MIGRATE_FUNCTIONS = {
     '0.5': migrate_v5_to_v6,
     '0.6': migrate_v6_to_v7,
     '0.7': migrate_v7_to_v8,
+    '0.8': migrate_v8_to_v9,
 }
 
 
-def migrate_recursively(metadata, data, folder):
-    """
-    Recursive migration of export files from v0.1 to newest version,
+def migrate_recursively(metadata, data, folder, version=EXPORT_VERSION):
+    """Recursive migration of export files from v0.1 to a newer version.
+
     See specific migration functions for detailed descriptions.
 
     :param metadata: the content of an export archive metadata.json file
     :param data: the content of an export archive data.json file
     :param folder: SandboxFolder in which the archive has been unpacked (workdir)
+    :param version: the version to migrate to, by default the current export version
     """
-    from aiida.tools.importexport import EXPORT_VERSION as newest_version
-
     old_version = verify_metadata_version(metadata)
 
+    type_check(version, str)
+
     try:
-        if old_version == newest_version:
-            echo.echo_critical('Your export file is already at the newest export version {}'.format(newest_version))
+        if old_version == version:
+            raise ArchiveMigrationError('Your export file is already at the version {}'.format(version))
+        elif old_version > version:
+            raise ArchiveMigrationError('Backward migrations are not supported')
         elif old_version in MIGRATE_FUNCTIONS:
             MIGRATE_FUNCTIONS[old_version](metadata, data, folder)
         else:
-            echo.echo_critical('Cannot migrate from version {}'.format(old_version))
+            raise ArchiveMigrationError('Cannot migrate from version {}'.format(old_version))
     except ValueError as exception:
-        echo.echo_critical(exception)
+        raise ArchiveMigrationError(exception)
     except DanglingLinkError:
-        echo.echo_critical('Export file is invalid because it contains dangling links')
+        raise ArchiveMigrationError('Export file is invalid because it contains dangling links')
 
     new_version = verify_metadata_version(metadata)
 
-    if new_version < newest_version:
-        new_version = migrate_recursively(metadata, data, folder)
+    if new_version < version:
+        new_version = migrate_recursively(metadata, data, folder, version)
 
     return new_version
