@@ -3,19 +3,19 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
 import os
-import ujson as uj
+import json
 
 ## Pagination defaults
 LIMIT_DEFAULT = 400
 PERPAGE_DEFAULT = 20
 
 ##Version prefix for all the URLs
-PREFIX="/api/v2"
+PREFIX='/api/v3'
 
 
 """
@@ -69,7 +69,7 @@ Schema customization (if file schema_custom.json is present in this same folder)
 schema_custom_config = os.path.join(os.path.split(__file__)[0], 'schema_custom.json')
 try:
     with open(schema_custom_config) as fin:
-        custom_schema = uj.load(fin)
+        custom_schema = json.load(fin)
 except IOError:
     custom_schema = {}
 
