@@ -22,7 +22,6 @@ from aiida.backends.sqlalchemy import manager
 from aiida.backends.sqlalchemy.models.base import Base
 from aiida.backends.sqlalchemy.utils import flag_modified
 from aiida.backends.testbase import AiidaTestCase
-from aiida.common.utils import Capturing
 from .test_utils import new_database
 
 
@@ -57,22 +56,28 @@ class TestMigrationsSQLA(AiidaTestCase):
         super().setUp()
         from aiida.orm import autogroup
 
-        self.current_autogroup = autogroup.current_autogroup
-        autogroup.current_autogroup = None
+        self.current_autogroup = autogroup.CURRENT_AUTOGROUP
+        autogroup.CURRENT_AUTOGROUP = None
         assert self.migrate_from and self.migrate_to, \
             "TestCase '{}' must define migrate_from and migrate_to properties".format(type(self).__name__)
 
         try:
-            with Capturing():
-                self.migrate_db_down(self.migrate_from)
+            self.migrate_db_down(self.migrate_from)
             self.setUpBeforeMigration()
-            with Capturing():
-                self.migrate_db_up(self.migrate_to)
+            self._perform_actual_migration()
         except Exception:
             # Bring back the DB to the correct state if this setup part fails
             self._reset_database_and_schema()
+            autogroup.CURRENT_AUTOGROUP = self.current_autogroup
             raise
 
+    def _perform_actual_migration(self):
+        """Perform the actual migration (upwards, to migrate_to).
+
+        Must be called after we are properly set to be in migrate_from.
+        """
+        self.migrate_db_up(self.migrate_to)
+
     def migrate_db_up(self, destination):
         """
         Perform a migration upwards (upgrade) with alembic
@@ -99,7 +104,7 @@ class TestMigrationsSQLA(AiidaTestCase):
         """
         from aiida.orm import autogroup
         self._reset_database_and_schema()
-        autogroup.current_autogroup = self.current_autogroup
+        autogroup.CURRENT_AUTOGROUP = self.current_autogroup
         super().tearDown()
 
     def setUpBeforeMigration(self):  # pylint: disable=invalid-name
@@ -116,8 +121,7 @@ class TestMigrationsSQLA(AiidaTestCase):
         of tests.
         """
         self.reset_database()
-        with Capturing():
-            self.migrate_db_up('head')
+        self.migrate_db_up('head')
 
     @property
     def current_rev(self):
@@ -210,29 +214,12 @@ class TestBackwardMigrationsSQLA(TestMigrationsSQLA):
     than the migrate_to revision.
     """
 
-    def setUp(self):
-        """
-        Go to the migrate_from revision, apply setUpBeforeMigration, then
-        run the migration.
-        """
-        AiidaTestCase.setUp(self)  # pylint: disable=bad-super-call
-        from aiida.orm import autogroup
+    def _perform_actual_migration(self):
+        """Perform the actual migration (downwards, to migrate_to).
 
-        self.current_autogroup = autogroup.current_autogroup
-        autogroup.current_autogroup = None
-        assert self.migrate_from and self.migrate_to, \
-            "TestCase '{}' must define migrate_from and migrate_to properties".format(type(self).__name__)
-
-        try:
-            with Capturing():
-                self.migrate_db_down(self.migrate_from)
-            self.setUpBeforeMigration()
-            with Capturing():
-                self.migrate_db_down(self.migrate_to)
-        except Exception:
-            # Bring back the DB to the correct state if this setup part fails
-            self._reset_database_and_schema()
-            raise
+        Must be called after we are properly set to be in migrate_from.
+        """
+        self.migrate_db_down(self.migrate_to)
 
 
 class TestMigrationEngine(TestMigrationsSQLA):
@@ -1003,7 +990,7 @@ class TestDbLogUUIDAddition(TestMigrationsSQLA):
     """
     Test that the UUID column is correctly added to the DbLog table and that the uniqueness
     constraint is added without problems (if the migration arrives until 375c2db70663 then the
-    constraint is added properly.
+    constraint is added properly).
     """
 
     migrate_from = '041a79fc615f'  # 041a79fc615f_dblog_cleaning
@@ -1655,3 +1642,69 @@ class TestDefaultLinkLabelMigration(TestMigrationsSQLA):
 
             finally:
                 session.close()
+
+
+class TestGroupTypeStringMigration(TestMigrationsSQLA):
+    """Test the migration that renames the DbGroup type strings."""
+
+    migrate_from = '118349c10896'  # 118349c10896_default_link_label.py
+    migrate_to = 'bf591f31dd12'  # bf591f31dd12_dbgroup_type_string.py
+
+    def setUpBeforeMigration(self):
+        """Create the DbGroups with the old type strings."""
+        DbGroup = self.get_current_table('db_dbgroup')  # pylint: disable=invalid-name
+        DbUser = self.get_current_table('db_dbuser')  # pylint: disable=invalid-name
+
+        with self.get_session() as session:
+            try:
+                default_user = DbUser(email='{}@aiida.net'.format(self.id()))
+                session.add(default_user)
+                session.commit()
+
+                # test user group type_string: 'user' -> 'core'
+                group_user = DbGroup(label='01', user_id=default_user.id, type_string='user')
+                session.add(group_user)
+                # test data.upf group type_string: 'data.upf' -> 'core.upf'
+                group_data_upf = DbGroup(label='02', user_id=default_user.id, type_string='data.upf')
+                session.add(group_data_upf)
+                # test auto.import group type_string: 'auto.import' -> 'core.import'
+                group_autoimport = DbGroup(label='03', user_id=default_user.id, type_string='auto.import')
+                session.add(group_autoimport)
+                # test auto.run group type_string: 'auto.run' -> 'core.auto'
+                group_autorun = DbGroup(label='04', user_id=default_user.id, type_string='auto.run')
+                session.add(group_autorun)
+
+                session.commit()
+
+                # Store values for later tests
+                self.group_user_pk = group_user.id
+                self.group_data_upf_pk = group_data_upf.id
+                self.group_autoimport_pk = group_autoimport.id
+                self.group_autorun_pk = group_autorun.id
+
+            finally:
+                session.close()
+
+    def test_group_string_update(self):
+        """Test that the type strings are properly migrated."""
+        DbGroup = self.get_current_table('db_dbgroup')  # pylint: disable=invalid-name
+
+        with self.get_session() as session:
+            try:
+                # test user group type_string: 'user' -> 'core'
+                group_user = session.query(DbGroup).filter(DbGroup.id == self.group_user_pk).one()
+                self.assertEqual(group_user.type_string, 'core')
+
+                # test data.upf group type_string: 'data.upf' -> 'core.upf'
+                group_data_upf = session.query(DbGroup).filter(DbGroup.id == self.group_data_upf_pk).one()
+                self.assertEqual(group_data_upf.type_string, 'core.upf')
+
+                # test auto.import group type_string: 'auto.import' -> 'core.import'
+                group_autoimport = session.query(DbGroup).filter(DbGroup.id == self.group_autoimport_pk).one()
+                self.assertEqual(group_autoimport.type_string, 'core.import')
+
+                # test auto.run group type_string: 'auto.run' -> 'core.auto'
+                group_autorun = session.query(DbGroup).filter(DbGroup.id == self.group_autorun_pk).one()
+                self.assertEqual(group_autorun.type_string, 'core.auto')
+            finally:
+                session.close()
